pub struct Command {
pub name: &'static str,
pub identify: Vec<&'static str>,
pub default: bool,
pub options: Vec<CommandOption>,
pub doc: &'static str,
pub page: Option<u32>,
}Fields
name: &'static stridentify: Vec<&'static str>The options that tell it from a namesake, as MAP tells SEND MAP from SEND.
default: boolThe namesake meant when none of the identify options is written, as TS is for READQ.
options: Vec<CommandOption>doc: &'static strThe command’s CICS TS 6.x topic.
page: Option<u32>Its page in the CICS TS 5.3 Application Programming Reference (SC34-7402-00).