pub enum CallArg<P = PlaceId, O = Operand> {
Reference(P),
Content(Chars<P, O>),
Value(O),
Omitted,
}Variants
Reference(P)
Content(Chars<P, O>)
Copied to a temporary; BY REFERENCE of anything but a data item passes as this. A literal’s bytes are those its own data item would hold; LENGTH OF is a binary fullword.
Value(O)
A fullword, an address or bytes, from the value.
Omitted