pub enum ConvertTable<P = PlaceId, O = Operand> {
Built(Vec<(u8, u8)>),
Operands {
from: Chars<P, O>,
to: Chars<P, O>,
},
}Variants
Built(Vec<(u8, u8)>)
Both operands literals: each distinct byte of the first with its byte of the second.
Operands
Operands of different lengths abend when the statement runs.