pub enum FileVerb {
Open(OpenMode),
Close,
CloseWith(Closing),
Read {
sequential: bool,
previous: bool,
into: Option<(PlaceId, MovePlan)>,
key: u8,
},
Write {
record: PlaceId,
from: Option<FromMove>,
advancing: Option<Advance>,
},
Rewrite {
record: PlaceId,
from: Option<FromMove>,
},
Delete,
Start {
rel: StartRel,
key: StartKey,
},
}Variants
Open(OpenMode)
Close
CloseWith(Closing)
Read
sequential: READ NEXT or PREVIOUS, or a file read in sequence, whose phrase is AT END;
otherwise the phrase is INVALID KEY and key the key of reference of an indexed file.
Write
record is located after FROM has moved into it.
Rewrite
Delete
Start