pub enum NumericFrom {
Value,
PackedCopy,
Float,
Zero,
Fill,
Zoned,
DeEdit {
edit: u32,
digits: u32,
scale: u32,
},
}Variants
Value
PackedCopy
NUMPROC(PFD), packed to packed of the same kind and scale: the bytes.
Float
Zero
Fill
A figurative other than ZERO, or an ALL literal: bytes filled, not converted.
Zoned
Alphanumeric bytes read as an unsigned zoned integer of their length.
DeEdit