pub struct ClassPart {
pub data: Program,
pub records: Vec<u32>,
}Expand description
FACTORY or OBJECT data: a program whose storage is the data as its VALUE clauses leave it, and the offset of each 01 or 77 record in it.
Fields
data: Programrecords: Vec<u32>Trait Implementations
impl Eq for ClassPart
impl StructuralPartialEq for ClassPart