pub struct RelativeKey {
pub place: PlaceId,
pub value: IntExpr,
pub store: StorePlan,
pub digits: Option<u32>,
}Expand description
The RELATIVE KEY: read as value, stored by store when a sequential READ or WRITE sets it,
and digits the integer digits that bound the record numbers it can hold (None: no bound).
Fields
place: PlaceIdvalue: IntExprstore: StorePlandigits: Option<u32>Trait Implementations
Sourceimpl Clone for RelativeKey
impl Clone for RelativeKey
Sourceimpl Debug for RelativeKey
impl Debug for RelativeKey
Sourceimpl Decode for RelativeKey
impl Decode for RelativeKey
impl Eq for RelativeKey
Sourceimpl PartialEq for RelativeKey
impl PartialEq for RelativeKey
impl StructuralPartialEq for RelativeKey