pub struct ReturnPoint {
pub frame: u64,
pub resume: Option<Resume>,
}Expand description
A return point armed at the end of a range’s last paragraph by frame frame, with the PERFORM’s
resume.
Fields
frame: u64resume: Option<Resume>Trait Implementations
Sourceimpl Clone for ReturnPoint
impl Clone for ReturnPoint
impl Copy for ReturnPoint
Sourceimpl Debug for ReturnPoint
impl Debug for ReturnPoint
Sourceimpl Decode for ReturnPoint
impl Decode for ReturnPoint
impl Eq for ReturnPoint
Sourceimpl PartialEq for ReturnPoint
impl PartialEq for ReturnPoint
impl StructuralPartialEq for ReturnPoint