Group

Struct Group 

pub struct Group<X = Comparand, V = ConstId, U = RangeId> {
    pub name: Option<String>,
    pub kind: GroupKind,
    pub level: usize,
    pub next_group: Option<NextGroup>,
    pub lines: Vec<Line<X, V>>,
    pub unprinted: Vec<Field<X, V>>,
    pub cross: Vec<(usize, Origin<X, V>)>,
    pub rolls: Vec<(usize, Origin<X, V>)>,
    pub totals: Vec<usize>,
    pub indicate: Option<usize>,
    pub declarative: Option<U>,
}

Fields

name: Option<String>kind: GroupKindlevel: usize

The control level of a CONTROL HEADING or FOOTING.

next_group: Option<NextGroup>lines: Vec<Line<X, V>>unprinted: Vec<Field<X, V>>

Fields with no COLUMN, which are set but not printed.

cross: Vec<(usize, Origin<X, V>)>

Cross-footing: SUM entries of this group adding entries of this group, in dependency order.

rolls: Vec<(usize, Origin<X, V>)>

Rolling forward: SUM entries elsewhere adding entries of this group.

totals: Vec<usize>

The SUM entries defined in this group, reset after it unless RESET defers them.

indicate: Option<usize>declarative: Option<U>

The USE BEFORE REPORTING section: its first and last paragraph.