Collating

Enum Collating 

pub enum Collating {
    Ebcdic,
    Positions(Rc<[u8; 256]>),
}
The order characters collate in: EBCDIC’s, or each byte’s position in a sequence, where bytes that collate equal share a position.

Variants



Ebcdic



Positions(Rc<[u8; 256]>)

Implementations

Source

impl Collating

pub fn ascii(page: &CodePage) -> Self

7-bit ASCII’s order, as ALPHABET IS STANDARD-1 gives it: the code page’s character for each ASCII code in turn, then every other byte in EBCDIC order.

pub fn of(collating: &Collating) -> Self

A program’s collating sequence.

pub fn is_ebcdic(&self) -> bool

pub fn collate(&self, bytes: &[u8]) -> Vec<u8> ⓘ

Each character’s position.