Event

Enum Event 

pub enum Event<'a> {
    Open {
        dd: &'a str,
        mode: OpenMode,
        path: &'a Path,
    },
    Close {
        dd: &'a str,
        path: &'a Path,
    },
    Load {
        program: &'a str,
        source: Option<&'a Path>,
    },
    Paragraph {
        program: &'a str,
        name: &'a str,
        index: usize,
    },
    Sink {
        kind: &'static str,
        file: &'a str,
        line: u32,
        operand: &'a str,
    },
}
What a run did that its evidence journal records: each file as it is opened and closed, each program CALL loads, with the source it was read from when a library supplied it, and each operation an input could steer, with its operand as the program’s code page reads it.

Variants



Open

Fields

dd: &'a str
path: &'a Path


Close

Fields

dd: &'a str
path: &'a Path


Load

Fields

program: &'a str
source: Option<&'a Path>


Paragraph

Control entering paragraph (or section header) index of program at its start.

Fields

program: &'a str
name: &'a str
index: usize


Sink

kind is cobolwork’s name for the sink (dynamic-program-load, log, …); file is the library file or COPY member the operation is in, empty for the first program’s own source.

Fields

kind: &'static str
file: &'a str
line: u32
operand: &'a str