pub struct FoundClass<C> {
pub code: C,
pub sources: Vec<String>,
}Expand description
A class definition a loader found and compiled, and its source table, its own source first by path when a program library supplied it.
Fields
code: Csources: Vec<String>Auto Trait Implementations
impl<C> Freeze for FoundClass<C>where
C: Freeze,
impl<C> RefUnwindSafe for FoundClass<C>where
C: RefUnwindSafe,
impl<C> Send for FoundClass<C>where
C: Send,
impl<C> Sync for FoundClass<C>where
C: Sync,
impl<C> Unpin for FoundClass<C>where
C: Unpin,
impl<C> UnsafeUnpin for FoundClass<C>where
C: UnsafeUnpin,
impl<C> UnwindSafe for FoundClass<C>where
C: UnwindSafe,