Job

Struct Job 

pub struct Job {
    pub files: Vec<String>,
}
The files an lp or lpr command prints, in order.

Fields

files: Vec<String>

Implementations

Source

impl Job

pub fn parse(command: &str) -> Option<Job>

The job command asks for when it is lp or lpr, with options CUPS documents, naming at least one file; None for any other command, including one that reads standard input.