pub struct Malformed {
pub offset: usize,
pub why: Why,
}Expand description
Where the document stops being well formed: the offset, in characters from the start of the document, of the first character in error, or of its end.
Fields
offset: usizewhy: WhyTrait Implementations
impl Copy for Malformed
impl Eq for Malformed
impl StructuralPartialEq for Malformed