pub struct Frame {
pub id: u64,
pub kind: FrameKind,
pub displaced: Option<ReturnPoint>,
pub segment: u8,
pub depth: u32,
pub temps: Vec<i64>,
}Expand description
An active range. displaced is the return point it replaced at its range’s end, put back when
it completes; segment the segment register when it was pushed, back when it completes. Its
paragraphs run at depth, and temps are the TIMES counters of the statements that run under
it, by TempId.
Fields
id: u64kind: FrameKinddisplaced: Option<ReturnPoint>segment: u8depth: u32temps: Vec<i64>Trait Implementations
impl Eq for Frame
impl StructuralPartialEq for Frame