pub trait SqlHost<'w, P: Copy, S>: Host<P> {
// Required methods
fn session(&mut self) -> Option<&mut Session<'w>>;
fn in_task(&self) -> bool;
fn program_id(&self) -> String;
fn text(&self, text: &S) -> String;
fn place_pos(&self, place: P) -> Pos;
fn untyped(&mut self, abend: AbendId) -> Abend;
// Provided method
fn locate_indicator(&mut self, place: P) -> Result<Loc, Abend> { ... }
}Expand description
What a statement asks of the executor running it beyond Host.
Required Methods
Sourcefn session(&mut self) -> Option<&mut Session<'w>>
fn session(&mut self) -> Option<&mut Session<'w>>
The run unit’s database session, when one is attached.
fn program_id(&self) -> String
fn text(&self, text: &S) -> String
Provided Methods
Sourcefn locate_indicator(&mut self, place: P) -> Result<Loc, Abend>
fn locate_indicator(&mut self, place: P) -> Result<Loc, Abend>
An indicator variable’s storage; an executor whose place for an indicator array named without subscripts is not its first element locates that element here.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".