pub fn string<P: Copy, O>(
x: &mut impl Values<P, O>,
into: P,
pointer: Option<P>,
sources: &[StringSource<P, O>],
pos: Pos,
) -> Result<bool, Abend>Expand description
STRING: returns whether it overflowed. The pointer is read before the first source and stored after the last, and each source is read after the ones before it are stored.